@@ -17,6 +17,7 @@ from .constants import MANTARRAY_NICKNAME_UUID
 from .constants import MANTARRAY_SERIAL_NUMBER_UUID
 from .constants import METADATA_UUID_DESCRIPTIONS
 from .constants import MICROSECONDS_PER_CENTIMILLISECOND
+from .constants import MIN_SUPPORTED_FILE_VERSION
 from .constants import PLATE_BARCODE_UUID
 from .constants import REF_SAMPLING_PERIOD_UUID
 from .constants import REFERENCE_VOLTAGE_UUID
@@ -36,20 +37,22 @@ from .constants import WELL_INDEX_UUID
 from .constants import WELL_NAME_UUID
 from .constants import WELL_ROW_UUID
 from .constants import XEM_SERIAL_NUMBER_UUID
+from .exceptions import FileAttributeNotFoundError
+from .exceptions import UnsupportedMantarrayFileVersionError
 from .exceptions import WellRecordingsNotFromSameSessionError
 from .files import PlateRecording
 from .files import WellFile
 
-try:  # adapted from https://packaging.python.org/guides/single-sourcing-package-version/
-    from importlib import metadata
-except ImportError:  # pragma: no cover
-    # Running on pre-3.8 Python; use importlib-metadata package
-    import importlib_metadata as metadata  # type: ignore # Eli (9/1/20): for some reason mypy is giving weird errors for this
-__version__: str = metadata.version("mantarray_file_manager")  # type: ignore # Eli (9/1/20): for some reason mypy is giving weird errors for this
+# try:  # adapted from https://packaging.python.org/guides/single-sourcing-package-version/
+#     from importlib import metadata
+# except ImportError:  # pragma: no cover
+#     # Running on pre-3.8 Python; use importlib-metadata package
+#     import importlib_metadata as metadata  # type: ignore # Eli (9/1/20): for some reason mypy is giving weird errors for this
+# __version__: str = metadata.version("mantarray_file_manager")  # type: ignore # Eli (9/1/20): for some reason mypy is giving weird errors for this
 
 __all__ = [
     "WellFile",
-    "__version__",
+    # "__version__",
     "PlateRecording",
     "UTC_BEGINNING_DATA_ACQUISTION_UUID",
     "START_RECORDING_TIME_INDEX_UUID",
@@ -85,4 +88,7 @@ __all__ = [
     "CENTIMILLISECONDS_PER_SECOND",
     "MICROSECONDS_PER_CENTIMILLISECOND",
     "WellRecordingsNotFromSameSessionError",
+    "MIN_SUPPORTED_FILE_VERSION",
+    "UnsupportedMantarrayFileVersionError",
+    "FileAttributeNotFoundError",
 ]
